==> eslint-plugin-typeorm-typescript-0.4.0.tgz: package/es/utils/relationType.js <==
import { AST_NODE_TYPES } from '@typescript-eslint/utils';
import { findObjectArgument, findReturnedValue, parseObjectLiteral } from './treeTraversal.js';
export function convertTypeToRelationType(arg) {
    var _a, _b;
    switch (arg.type) {
        case AST_NODE_TYPES.TSTypeReference: {
            const name = arg.typeName.type === AST_NODE_TYPES.Identifier ? arg.typeName.name : '';
            const param = (_b = (_a = arg.typeArguments) === null || _a === void 0 ? void 0 : _a.params) === null || _b === void 0 ? void 0 : _b[0];
            if (name === 'Promise' && param) {
                return Object.assign(Object.assign({}, convertTypeToRelationType(param)), { isLazy: true });
            }
            return {
                name,
                isArray: false,
                isLazy: false,
                nullable: false,
            };
        }
        case AST_NODE_TYPES.TSArrayType: {
            const item = convertTypeToRelationType(arg.elementType);
            return Object.assign(Object.assign({}, item), { isArray: true });
        }
        case AST_NODE_TYPES.TSNullKeyword: {
            return { name: '', isArray: false, isLazy: false, nullable: true };
        }
        case AST_NODE_TYPES.TSUnionType: {
            return arg.types.reduce((acc, currentNode) => {
                const current = convertTypeToRelationType(currentNode);
                return {
                    name: acc.name || current.name,
                    isArray: acc.isArray || current.isArray,
                    isLazy: acc.isLazy || current.isLazy,
                    nullable: acc.nullable || current.nullable,
                };
            }, {
                name: '',
                isArray: false,
                isLazy: false,
                nullable: false,
            });
        }
        default: {
            return { name: '', isArray: false, isLazy: false, nullable: false };
        }
    }
}
export function convertArgumentToRelationType(relation, args) {
    var _a;
    const [otherEntityFn, ...restArguments] = args;
    const otherEntity = findReturnedValue(otherEntityFn);
    if (!otherEntity) {
        return undefined;
    }
    // OneToMany, ManyToMany
    if (relation === 'OneToMany' || relation === 'ManyToMany') {
        return { name: otherEntity, isArray: true, isLazy: false, nullable: false };
    }
    // OneToOne, ManyToOne
    const options = findObjectArgument(restArguments);
    const parsedOptions = parseObjectLiteral(options);
    return {
        name: otherEntity,
        isArray: false,
        isLazy: false,
        nullable: (_a = parsedOptions === null || parsedOptions === void 0 ? void 0 : parsedOptions.nullable) !== null && _a !== void 0 ? _a : true,
    };
}
export function isTypesEqual(toType, tsType) {
    // Just check field equality
    return (toType.name === tsType.name &&
        toType.nullable === tsType.nullable &&
        toType.isArray === tsType.isArray);
}
// Relations are nullable by default which can be confusing, help with a custom message
export function isTypeMissingNullable(toType, tsType) {
    // Check if the relation should be nullable but not
    return toType.name === tsType.name && toType.nullable && !tsType.nullable;
}
// Relations are nullable by default which can be confusing, help with a custom message
export function isTypeMissingArray(toType, tsType) {
    // Check if the relation should be an array but not
    return toType.name === tsType.name && toType.isArray && !tsType.isArray;
}
export function typeToString(relation, { isLazy }) {
    let result = relation.name;
    if (relation.isArray) {
        result += '[]';
    }
    if (relation.nullable) {
        result += ' | null';
    }
    if (isLazy) {
        result = `Promise<${result}>`;
    }
    return result;
}

==> eslint-plugin-typeorm-typescript-0.5.0.tgz: package/es/utils/relationType.js <==
import { AST_NODE_TYPES } from '@typescript-eslint/utils';
import { findObjectArgument, findReturnedValue, parseObjectLiteral } from './treeTraversal.js';
export function convertTypeToRelationType(arg) {
    var _a, _b;
    switch (arg.type) {
        case AST_NODE_TYPES.TSTypeReference: {
            const name = arg.typeName.type === AST_NODE_TYPES.Identifier ? arg.typeName.name : '';
            const param = (_b = (_a = arg.typeArguments) === null || _a === void 0 ? void 0 : _a.params) === null || _b === void 0 ? void 0 : _b[0];
            if (name === 'Promise' && param) {
                return Object.assign(Object.assign({}, convertTypeToRelationType(param)), { isLazy: true });
            }
            if (name === 'Relation' && param) {
                return Object.assign(Object.assign({}, convertTypeToRelationType(param)), { isWrapped: true });
            }
            return {
                name,
                isArray: false,
                isLazy: false,
                nullable: false,
                isWrapped: false,
            };
        }
        case AST_NODE_TYPES.TSArrayType: {
            const item = convertTypeToRelationType(arg.elementType);
            return Object.assign(Object.assign({}, item), { isArray: true });
        }
        case AST_NODE_TYPES.TSNullKeyword: {
            return { name: '', isArray: false, isLazy: false, nullable: true, isWrapped: false };
        }
        case AST_NODE_TYPES.TSUnionType: {
            return arg.types.reduce((acc, currentNode) => {
                const current = convertTypeToRelationType(currentNode);
                return {
                    name: acc.name || current.name,
                    isArray: acc.isArray || current.isArray,
                    isLazy: acc.isLazy || current.isLazy,
                    isWrapped: acc.isWrapped || current.isWrapped,
                    nullable: acc.nullable || current.nullable,
                };
            }, {
                name: '',
                isArray: false,
                isLazy: false,
                nullable: false,
                isWrapped: false,
            });
        }
        default: {
            return { name: '', isArray: false, isLazy: false, nullable: false, isWrapped: false };
        }
    }
}
export function convertArgumentToRelationType(relation, args) {
    var _a;
    const [otherEntityFn, ...restArguments] = args;
    const otherEntity = findReturnedValue(otherEntityFn);
    if (!otherEntity) {
        return undefined;
    }
    // OneToMany, ManyToMany
    if (relation === 'OneToMany' || relation === 'ManyToMany') {
        return {
            name: otherEntity,
            isArray: true,
            isLazy: false,
            isWrapped: false,
            nullable: false,
        };
    }
    // OneToOne, ManyToOne
    const options = findObjectArgument(restArguments);
    const parsedOptions = parseObjectLiteral(options);
    return {
        name: otherEntity,
        isArray: false,
        isLazy: false,
        isWrapped: false,
        nullable: (_a = parsedOptions === null || parsedOptions === void 0 ? void 0 : parsedOptions.nullable) !== null && _a !== void 0 ? _a : true,
    };
}
export function isTypesEqual(toType, tsType) {
    // Just check field equality
    return (toType.name === tsType.name &&
        toType.nullable === tsType.nullable &&
        toType.isArray === tsType.isArray);
}
// Relations are nullable by default which can be confusing, help with a custom message
export function isTypeMissingNullable(toType, tsType) {
    // Check if the relation should be nullable but not
    return toType.name === tsType.name && toType.nullable && !tsType.nullable;
}
// Relations are nullable by default which can be confusing, help with a custom message
export function isTypeMissingArray(toType, tsType) {
    // Check if the relation should be an array but not
    return toType.name === tsType.name && toType.isArray && !tsType.isArray;
}
export function typeToString(relation, { isLazy, isWrapped }) {
    let result = relation.name;
    if (relation.isArray) {
        result += '[]';
    }
    if (relation.nullable) {
        result += ' | null';
    }
    if (isWrapped) {
        result = `Relation<${result}>`;
    }
    if (isLazy) {
        result = `Promise<${result}>`;
    }
    return result;
}
